@@ -80,7 +80,7 @@ void dumpContentHelper(KMime::Content *part, const QString &partId = QString())
 void listFolders(Session *session, bool includeUnsubscribed = false, const QString &nameFilter = QLatin1String(""))
 {
     auto list = new ListJob(session);
-    list->setIncludeUnsubscribed(includeUnsubscribed);
+    list->setOption(includeUnsubscribed ? KIMAP::ListJob::IncludeUnsubscribed : KIMAP::ListJob::NoOption);
     list->exec();
     Q_ASSERT_X(list->error() == 0, "ListJob", list->errorString().toLocal8Bit().constData());
     int count = list->mailBoxes().size();
